@@ -1,11 +1,8 @@
 # Copyright 2022 Canonical Ltd.
 # See LICENSE file for licensing details.
-__version__ = "0.0.4"
+__version__ = "0.0.5"
 
 # flake8: noqa: F401,F402
 
-from . import errors
-from . import events
-from . import relation
+from . import errors, events, relation, testing
 from .relation import EndpointWrapper
-from . import testing
